@@ -41,7 +41,7 @@ m3=Contorno2(img2 = t(img))
 m4=m2+t(m3)
 m5=1*(m4!=0)
 m5=EBImage::as.Image(m5)
-if(plot==TRUE) {plot_image(m5)}
+if(plot==TRUE) {plot(m5)}
 m5
 }
 
