@@ -5,7 +5,7 @@
 #' @description This function changes the brightness, contrast and makes the
 #'   gamma adjustment in the image (Esta funcao permite mudar o brilho,
 #'   contraste e fazer um ajuste gamma na imagem).
-#' @usage edit_image(im,brightness=0,contrast=1,gamma =1,plot=T)
+#' @usage edit_image(im,brightness=0,contrast=1,gamma =1,plot=TRUE)
 
 #' @param im    :This object must contain an image in EBImage format (Este
 #'   objeto deve conter uma imagem no formato do EBImage).
@@ -68,7 +68,7 @@
 
 
 
-edit_image=function(im,brightness=0,contrast=1,gamma =1,plot=T){
+edit_image=function(im,brightness=0,contrast=1,gamma =1,plot=TRUE){
   if( EBImage::is.Image(im)){
     im@.Data=im@.Data+brightness
     im@.Data=im@.Data*contrast
