@@ -137,12 +137,14 @@ join_image=function(im1=NULL,im2=NULL,im3=NULL,im4=NULL,im5=NULL,bk=c(1,1,1), nc
       nrow=ceiling(nn/ncol)
     }
 if(!is.null(ncol)){nrow=ceiling(nn/ncol)}
+    oldpar <- par(no.readonly = TRUE) # code line i
     op <- par(mfrow = c(nrow, ncol))
    # op
     for(i in 1:nn){
       plot(EBImage::as.Image(mat[,,i]))
     }
-    op <- par(mfrow = c(1, 1))
+    #op <- par(mfrow = c(1, 1))
+    on.exit(par(oldpar))
   }
 
 
