@@ -4,7 +4,7 @@
 #' @description Esta funcao permite dividir a imagem e obter medidas dos objetos
 #' @usage split_image(im,Seg,noise=0,CutImage=TRUE,lim=10,tolerance=1,ext=1,
 #'   splitConnected=FALSE,colorBack=c(0,0,0) ,saveImage=TRUE,
-#'   plot=T,col="red",cex=1,fileName="test.jpg")
+#'   plot=TRUE,col="red",cex=1,fileName="test.jpg")
 #'
 #' @param im Este objeto deve conter uma imagem no formato do EBImage.
 #' @param Seg Este objeto deve ser obrigatoriamente uma matriz binaria, contendo
@@ -65,7 +65,7 @@
 split_image=function(im,Seg,noise=0,CutImage=TRUE,lim=10,tolerance=1,
                      ext=1,splitConnected=FALSE,colorBack=c(0,0,0) ,
                      saveImage=TRUE,
-                     plot=T,col="red",cex=1,
+                     plot=TRUE,col="red",cex=1,
                      fileName="test.jpg"){
   r=colorBack[1]
   g=colorBack[2]
