@@ -15,19 +15,19 @@ im=read_image(end,plot=TRUE)
 
 ## -----------------------------------------------------------------------------
 ##Diminuir a resolucao (tamanho da imagem)
-im2=resize_image(im,w=1000,plot=TRUE)
+im2=resize_image(im,w=1000,plot=FALSE)
 
 ##Cortar Imagem
-im3=crop_image(im2,w =200:650,h=100:450,plot = TRUE)
+im3=crop_image(im2,w =200:650,h=100:450,plot = FALSE)
 
 ##Aumentar brilho
-im4=edit_image(im3,brightness = 0.1,plot = TRUE)
+im4=edit_image(im3,brightness = 0.1,plot = FALSE)
 
 #Aumentar contraste
-im5=edit_image(im4,contrast = 1.2,plot = TRUE)
+im5=edit_image(im4,contrast = 1.2,plot = FALSE)
 
 #Aumentar gamma
-im6=edit_image(im5,gamma  = 1.1,plot = TRUE)
+im6=edit_image(im5,gamma  = 1.1,plot = FALSE)
 
 
 #Alterando brilho, contraste e gamma
