@@ -48,7 +48,7 @@ medidas
 # A area conhecida do objeto de referência tem 8.5 x 5.5 cm 
 #e sua areasegmentada esta no objeto ref.seg
 
-medidasref=measure_image(img = folhas.seg,noise =1000,id=ref.seg,length =8.5,width =5.5 )
+medidasref=measure_image(img = folhas.seg,noise =1000,id=ref.seg,length =8.5,width =5.5,plot = FALSE )
 #numero de objetos e medias
 medidasref
 
